@@ -84,7 +84,7 @@ class Settings:
 
     @property
     def FLAVIUS_API_PAGE_FETCH(self):
-        return getattr(settings, "FLAVIUS_API_ORDER_DECIDE", 'api/pages.php')
+        return getattr(settings, "FLAVIUS_API_PAGE_FETCH", 'api/pages.php')
 
     @property
     def FLAVIUS_API_CREDIT_ADD(self):
